function NYQprintSpec (M, NCof, dev, BSpec, fid)
% This routine prints the design parameters for an FIR Nyquist filter.

% $Id: NYQprintSpec.m,v 1.2 2009/07/07 20:23:19 pkabal Exp $

if (~ exist ('fid', 'var'))
  fid = 1;
end

dBV = @(x)(20 * log10 (x));

DFM_NYQ = 'Linear Phase FIR Nyquist Filter';
DIMF_Pars = ' No. Coef: %d, Zero Crossing Int.: %d\n';
DFMP_NYQheader = ...
'           Freq.      Value     Weight           Limits     Deviation  Dev dB';
DFMP_BandS = 'Band %2d:%7.4f %10.3g %10.3g ';
DFMP_BandC = '        %7.4f %10.3g %10.3g ';

% Preamble
fprintf (fid, '%s\n', DFM_NYQ);
fprintf (fid, DIMF_Pars, NCof, M);
fprintf (fid, '%s\n', DFMP_NYQheader);

% Design specifications
NBand = length (BSpec);
for (k = 1:NBand)

  NVal = length (BSpec(k).f);
  for (i = 1:NVal)

    if (i == 1)
      fprintf (fid, DFMP_BandS, k, BSpec(k).f(i), BSpec(k).V(i), BSpec(k).W(i));
    else
      fprintf (fid, DFMP_BandC,    BSpec(k).f(i), BSpec(k).V(i), BSpec(k).W(i));
    end

    % Limits
    if (isinf (BSpec(k).LL(i)))
      fprintf (fid, '      ---- ');
    else
      fprintf (fid, '%10.3g ', BSpec(k).LL(i));
    end
    if (isinf (BSpec(k).UL(i)))
      fprintf (fid, '      ---- ');
    else
      fprintf (fid, '%10.3g ', BSpec(k).UL(i));
    end

    % Calculate the deviation
    devW = dev / BSpec(k).W(i);    % Weighted deviation
    excU = min (BSpec(k).V(i) + devW, BSpec(k).UL(i));
    excL = max (BSpec(k).V(i) - devW, BSpec(k).LL(i));
    devWM = max (excU - BSpec(k).V(i), BSpec(k).V(i) - excL);
    fprintf (fid, '%9.2g', devWM);
 
    % The printed deviation in dB is the larger of the dB value of
    % the plus excursion or the minus excursion.
    if (devWM > 0)
      if (BSpec(k).V(i) ~= 0 && excL > 0)
        RU = excU / BSpec(k).V(i);
        RL = BSpec(k).V(i) / excL;
        devdB = dBV (max (RU, RL));
      else
        devdB = dBV (devWM);
      end
      fprintf (fid, ' %7.2f', devdB);
    else
      fprintf (fid, '    ****');
    end
    fprintf (fid, '\n');

  end
end

return
